@@ -68,6 +68,8 @@ class RedditContentObject(object):
         self.reddit_session = reddit_session
         self._underscore_names = underscore_names
         self.has_fetched = self._populate(json_dict, fetch)
+        self.json_dict = (json_dict if reddit_session.config.store_json_result
+                          is True else None)
 
     def __eq__(self, other):
         return (isinstance(other, RedditContentObject) and
@@ -121,6 +123,9 @@ class RedditContentObject(object):
     def _populate(self, json_dict, fetch):
         if json_dict is None:
             json_dict = self._get_json_dict() if fetch else {}
+            self.json_dict = (json_dict
+                              if self.reddit_session.config.store_json_result
+                              is True else None)
 
         # TODO: Remove this wikipagelisting hack
         if isinstance(json_dict, list):
@@ -303,7 +308,7 @@ class Hideable(RedditContentObject):
 
 class Inboxable(RedditContentObject):
 
-    """Interface for Reddit content objects that appear in the Inbox."""
+    """Interface for objects that appear in the inbox (orangereds)."""
 
     def mark_as_read(self):
         """Mark object as read.
@@ -567,7 +572,7 @@ class Comment(Editable, Inboxable, Moderatable, Reportable, Voteable):
 
 class Message(Inboxable):
 
-    """A class for reddit messages (orangereds)."""
+    """A class for private messages."""
 
     def __init__(self, reddit_session, json_dict):
         super(Message, self).__init__(reddit_session, json_dict)
