@@ -26,6 +26,7 @@ import sys
 import time
 import unittest
 import uuid
+import warnings
 from functools import wraps
 from requests.compat import urljoin
 from requests.exceptions import HTTPError
@@ -224,6 +225,22 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def setUp(self):
         self.configure()
 
+    def test_base_36_conversion(self):
+        self.assertEquals(helpers.convert_numeric_id_to_id36(295), '87')
+        self.assertEquals(helpers.convert_id36_to_numeric_id('87'), 295)
+
+        self.assertEquals(helpers.convert_numeric_id_to_id36(275492), '5wkk')
+        self.assertEquals(helpers.convert_id36_to_numeric_id('5wkk'), 275492)
+
+        self.assertRaises(TypeError, helpers.convert_numeric_id_to_id36)
+        self.assertRaises(ValueError, helpers.convert_numeric_id_to_id36, '1')
+        self.assertRaises(ValueError, helpers.convert_numeric_id_to_id36, -1)
+
+        self.assertRaises(TypeError, helpers.convert_id36_to_numeric_id)
+        self.assertRaises(ValueError, helpers.convert_id36_to_numeric_id,
+                          't3_87')
+        self.assertRaises(ValueError, helpers.convert_id36_to_numeric_id, 87)
+
     def test_comments_contains_no_noncomment_objects(self):
         comments = self.r.get_submission(url=self.comment_url).comments
         self.assertFalse([item for item in comments if not
@@ -239,6 +256,10 @@ class BasicTest(unittest.TestCase, BasicHelper):
         self.assertTrue(text.startswith('<'))
         self.assertTrue(text.endswith('>'))
 
+    def test_deprecation(self):
+        with warnings.catch_warnings():
+            self.r.get_all_comments()
+
     def test_equality(self):
         subreddit = self.r.get_subreddit(self.sr)
         same_subreddit = self.r.get_subreddit(self.sr)
@@ -373,6 +394,20 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def test_search_reddit_names(self):
         self.assertTrue(self.r.search_reddit_names('reddit'))
 
+    def test_store_json_result(self):
+        self.r.config.store_json_result = True
+        sub_url = ('http://www.reddit.com/r/reddit_api_test/comments/'
+                   '1f7ojw/oauth_submit/')
+        sub = self.r.get_submission(url=sub_url)
+        self.assertEqual(sub.json_dict['url'], sub_url)
+
+    def test_store_lazy_json_result(self):
+        self.r.config.store_json_result = True
+        subreddit = self.r.get_subreddit(self.sr)
+        # Force object to load
+        subreddit.title
+        self.assertEqual(subreddit.json_dict['display_name'], self.sr)
+
     #def test_timeout(self):
     #    self.assertRaises(Timeout, helpers._request, self.r,
     #                      self.r.config['comments'], timeout=0.001)
@@ -901,7 +936,7 @@ class ImageTests(unittest.TestCase, AuthenticatedHelper):
     def test_upload_invalid_file_path(self):
         self.assertRaises(IOError, self.subreddit.upload_image, 'nonexistent')
 
-    def test_upload_uerinvalid_image(self):
+    def test_upload_invalid_image(self):
         image = self.image_path.format('white-square.tiff')
         self.assertRaises(errors.ClientException, self.subreddit.upload_image,
                           image)
@@ -1396,22 +1431,6 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
         self.configure()
         self.other_user = self.r.get_redditor(self.other_user_name)
 
-    def test_add_remove_friends(self):
-        def verify_add():
-            self.other_user.friend()
-            self.assertTrue(self.other_user in self.r.user.get_friends())
-
-        def verify_remove():
-            self.other_user.unfriend()
-            self.assertTrue(self.other_user not in self.r.user.get_friends())
-
-        if self.other_user in self.r.user.get_friends():
-            verify_remove()
-            verify_add()
-        else:
-            verify_add()
-            verify_remove()
-
     def test_duplicate_login(self):
         self.r.login(self.other_user_name, self.other_user_pswd)
 
@@ -1422,6 +1441,12 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
         self.delay()  # The queue needs to be processed
         self.assertFalse(item in self.r.user.get_liked())
 
+    def test_get_friends(self):
+        # See issue 175.
+        # If this test fails and doesn't raise an exception, but smoothly calls
+        # self.r.user.get_friends, then issue 175 has been resolved.
+        self.assertRaises(errors.RedirectException, self.r.user.get_friends)
+
     def test_get_hidden(self):
         submission = next(self.r.user.get_submitted())
         submission.hide()
@@ -1603,6 +1628,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.configure()
 
     def test_clear_vote(self):
+        self.disable_cache()
         predicate = lambda submission: submission.likes is False
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.clear_vote()
@@ -1611,6 +1637,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertEqual(submission.likes, None)
 
     def test_delete(self):
+        self.disable_cache()
         submission = list(self.r.user.get_submitted())[-1]
         submission.delete()
         # reload the submission
@@ -1618,6 +1645,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertEqual(None, submission.author)
 
     def test_downvote(self):
+        self.disable_cache()
         predicate = lambda submission: submission.likes is True
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.downvote()
@@ -1647,6 +1675,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.first(self.r.get_subreddit(self.sr).get_reports(), predicate)
 
     def test_save(self):
+        self.disable_cache()
         predicate = lambda submission: not submission.saved
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.save()
@@ -1695,6 +1724,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertFalse(submission.hidden)
 
     def test_unsave(self):
+        self.disable_cache()
         predicate = lambda submission: submission.saved
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.unsave()
@@ -1703,6 +1733,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertFalse(submission.saved)
 
     def test_upvote(self):
+        self.disable_cache()
         predicate = lambda submission: submission.likes is None
         submission = self.first(self.r.user.get_submitted(), predicate)
         submission.upvote()
